pub struct Svg { /* private fields */ }image or svg or canvas only.Expand description
An SVG image widget
May be default constructed (result is empty).
The size of the widget is inferred from the SVG source in logical pixels then scaled by the display’s scale factor. If a different size should be used it must be set after loading the SVG data.
By default, the drawn SVG will not be allowed to scale above its specified size; if the widget is forced to stretch, content will be positioned within this space according to alignment rules (centered by default).
Implementations
Sourceimpl Svg
impl Svg
Sourcepub fn new(data: &'static [u8]) -> Result<Svg, impl Error>
pub fn new(data: &'static [u8]) -> Result<Svg, impl Error>
Construct from data
Returns an error if the SVG fails to parse. If using this method
with include_bytes it is probably safe to unwrap.
The (logical) size of the widget is set to that from the SVG source.
Sourcepub fn load(
&mut self,
cx: &mut ConfigCx<'_>,
data: &'static [u8],
resources_dir: Option<&Path>,
) -> Result<(), impl Error + use<>>
pub fn load( &mut self, cx: &mut ConfigCx<'_>, data: &'static [u8], resources_dir: Option<&Path>, ) -> Result<(), impl Error + use<>>
Load from data
Replaces existing data and request a resize. The size is inferred from the SVG using units of logical pixels.
Sourcepub fn load_path<P>(
&mut self,
cx: &mut ConfigCx<'_>,
path: P,
) -> Result<(), impl Error + use<P>>
pub fn load_path<P>( &mut self, cx: &mut ConfigCx<'_>, path: P, ) -> Result<(), impl Error + use<P>>
Load from a path
This is a wrapper around Self::load.
Sourcepub fn set_logical_size(&mut self, size: impl Into<LogicalSize>)
pub fn set_logical_size(&mut self, size: impl Into<LogicalSize>)
Set size in logical pixels
Sourcepub fn with_logical_size(self, size: impl Into<LogicalSize>) -> Svg
pub fn with_logical_size(self, size: impl Into<LogicalSize>) -> Svg
Set size in logical pixels (inline)
Sourcepub fn with_margin_style(self, style: MarginStyle) -> Svg
pub fn with_margin_style(self, style: MarginStyle) -> Svg
Set the margin style (inline)
By default, this is MarginStyle::Large.
Sourcepub fn with_fixed_aspect_ratio(self, fixed: bool) -> Svg
pub fn with_fixed_aspect_ratio(self, fixed: bool) -> Svg
Control whether the aspect ratio is fixed (inline)
By default this is fixed.
Sourcepub fn with_stretch(self, stretch: Stretch) -> Svg
pub fn with_stretch(self, stretch: Stretch) -> Svg
Set the stretch factor (inline)
By default this is Stretch::None. Particular to this widget,
Stretch::None will avoid stretching of content, aligning instead.