pub struct PathStroker { /* private fields */ }Available on crate features
image or svg or canvas only.Expand description
A path stroker.
Implementations
Sourceimpl PathStroker
impl PathStroker
Sourcepub fn new() -> PathStroker
pub fn new() -> PathStroker
Creates a new PathStroker.
Sourcepub fn compute_resolution_scale(ts: &Transform) -> f32
pub fn compute_resolution_scale(ts: &Transform) -> f32
Computes a resolution scale.
Resolution scale is the “intended” resolution for the output. Default is 1.0.
Larger values (res > 1) indicate that the result should be more precise, since it will be zoomed up, and small errors will be magnified.
Smaller values (0 < res < 1) indicate that the result can be less precise, since it will be zoomed down, and small errors may be invisible.