pub struct LogicalBuilder { /* private fields */ }Expand description
SizeRules builder
Implementations
Sourceimpl LogicalBuilder
impl LogicalBuilder
Sourcepub fn new(size: impl Into<LogicalSize>, scale_factor: f32) -> LogicalBuilder
pub fn new(size: impl Into<LogicalSize>, scale_factor: f32) -> LogicalBuilder
Construct from mandatory arguments: size and scale_factor
Sourcepub fn with_ideal_factor(self, factor: f32) -> LogicalBuilder
pub fn with_ideal_factor(self, factor: f32) -> LogicalBuilder
Set the ideal size factor
The minimum size is set directly from the input size. The ideal size is
set from the minimum multiplied by the ideal factor.
By default this is 1.0.
Sourcepub fn with_margin(self, margin: f32) -> LogicalBuilder
pub fn with_margin(self, margin: f32) -> LogicalBuilder
Set all margins (symmetric)
All margins are set to the same value. By default these are 0.0.
Sourcepub fn with_stretch(self, stretch: Stretch) -> LogicalBuilder
pub fn with_stretch(self, stretch: Stretch) -> LogicalBuilder
Set the stretch priority
By default this is Stretch::None.
Sourcepub fn build(self, axis: impl Directional) -> SizeRules
pub fn build(self, axis: impl Directional) -> SizeRules
Build SizeRules