pub struct WgpuBuilder<CB: CustomPipeBuilder> { /* private fields */ }Available on crate feature
wgpu only.Expand description
Builder for a WGPU Runner’s graphics instance
Implementations
Sourceimpl<CB: CustomPipeBuilder> WgpuBuilder<CB>
impl<CB: CustomPipeBuilder> WgpuBuilder<CB>
Sourcepub fn with_wgpu_options(self, options: Options) -> Self
pub fn with_wgpu_options(self, options: Options) -> Self
Specify the default WGPU options
These options serve as a default, but may still be replaced by values
read from env vars unless disabled via Self::read_env_vars.
Sourcepub fn read_env_vars(self, read_env_vars: bool) -> Self
pub fn read_env_vars(self, read_env_vars: bool) -> Self
En/dis-able reading options from environment variables
Default: true. If enabled, options will be read from env vars where
present (see kas_wgpu::Options::load_from_env).
Sourcepub fn with_default_theme(self) -> Builder<FlatTheme, Instance<CB>>
pub fn with_default_theme(self) -> Builder<FlatTheme, Instance<CB>>
Use a selected theme
Sourcepub fn with_theme<T>(self, theme: T) -> Builder<T, Instance<CB>>
pub fn with_theme<T>(self, theme: T) -> Builder<T, Instance<CB>>
Use a specified theme