pub struct Image { /* private fields */ }image or svg or canvas only.Expand description
A raster image widget, loaded from a path
If your image source is not a path, use Sprite instead. Note also
that since image-loading can be CPU- and IO-intensive, if images get
reloaded frequently, you might benefit from using Sprite over a
custom image loader with a cache.
Size is inferred from the loaded image. By default, scaling is limited to integer multiples of the source image size.
May be default constructed (result is empty).
Implementations
Sourceimpl Image
impl Image
Sourcepub fn new(path: impl Into<PathBuf>) -> Image
pub fn new(path: impl Into<PathBuf>) -> Image
Construct with a given path
The image will be loaded when the widget is configured.
Sourcepub fn set_logical_size(&mut self, size: impl Into<LogicalSize>)
pub fn set_logical_size(&mut self, size: impl Into<LogicalSize>)
Set size in logical pixels
This enables fractional scaling of the image with a fixed aspect ratio.
Sourcepub fn with_logical_size(self, size: impl Into<LogicalSize>) -> Image
pub fn with_logical_size(self, size: impl Into<LogicalSize>) -> Image
Set size in logical pixels (inline)
This enables fractional scaling of the image with a fixed aspect ratio.
Sourcepub fn with_margin_style(self, style: MarginStyle) -> Image
pub fn with_margin_style(self, style: MarginStyle) -> Image
Set the margin style (inline)
By default, this is MarginStyle::Large.
Sourcepub fn with_fixed_aspect_ratio(self, fixed: bool) -> Image
pub fn with_fixed_aspect_ratio(self, fixed: bool) -> Image
Control whether the aspect ratio is fixed (inline)
This is only applicable when using fractional scaling (see
Self::set_logical_size) since integer scaling always uses a
fixed aspect ratio. By default this is enabled.
Sourcepub fn with_stretch(self, stretch: Stretch) -> Image
pub fn with_stretch(self, stretch: Stretch) -> Image
Set the stretch factor (inline)
By default this is Stretch::None. Particular to this widget,
Stretch::None will avoid stretching of content, aligning instead.