pub trait RoleCx {
// Required method
fn set_label_impl(&mut self, label: TextOrSource<'_>);
}Expand description
Context through which additional role properties may be specified
Unlike other widget method contexts, this is a trait; the caller provides an implementation.
Required Methods
Sourcefn set_label_impl(&mut self, label: TextOrSource<'_>)
fn set_label_impl(&mut self, label: TextOrSource<'_>)
Attach a label
Do not use this for Role::Label and similar items where the label is
the widget’s primary value. Do use this where a label exists which is
not the primary value, for example an image’s alternate text or a label
next to a control.